==> holado-0.13.8.tar.gz: holado-0.13.8/src/holado_test/tools/test_server/server/rest/api/campaign/scenario.py <==
#################################################
# HolAdo (Holistic Automation do)
#
# (C) Copyright 2021-2025 by Eric Klumpp
# 
# Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation files (the “Software”), to deal in the Software without restriction, including without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to the following conditions:
# 
# The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.

# The Software is provided “as is”, without warranty of any kind, express or implied, including but not limited to the warranties of merchantability, fitness for a particular purpose and noninfringement. In no event shall the authors or copyright holders be liable for any claim, damages or other liability, whether in an action of contract, tort or otherwise, arising from, out of or in connection with the software or the use or other dealings in the Software.
#################################################

from flask.views import MethodView
from holado.common.context.session_context import SessionContext


def _get_session_context():
    return SessionContext.instance()


class HistoryView(MethodView):
    
    def get(self, body: dict):
        scenario_name = body.get('scenario_name') if body else None
        size = body.get('size') if body else None
        
        res = _get_session_context().server_manager.campaign_manager.get_scenario_history(scenario_name=scenario_name, size=size)
        return res

==> holado-0.13.9.tar.gz: holado-0.13.9/src/holado_test/tools/test_server/server/rest/api/campaign/scenario.py <==
#################################################
# HolAdo (Holistic Automation do)
#
# (C) Copyright 2021-2025 by Eric Klumpp
# 
# Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation files (the “Software”), to deal in the Software without restriction, including without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to the following conditions:
# 
# The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.

# The Software is provided “as is”, without warranty of any kind, express or implied, including but not limited to the warranties of merchantability, fitness for a particular purpose and noninfringement. In no event shall the authors or copyright holders be liable for any claim, damages or other liability, whether in an action of contract, tort or otherwise, arising from, out of or in connection with the software or the use or other dealings in the Software.
#################################################

from flask.views import MethodView
from holado.common.context.session_context import SessionContext
import logging


logger = logging.getLogger(__name__)


def _get_session_context():
    return SessionContext.instance()


class HistoryView(MethodView):
    
    def get(self, body: dict=None):
        try:
            scenario_name = body.get('scenario_name') if body else None
            size = body.get('size') if body else None
            
            return _get_session_context().server_manager.campaign_manager.get_scenario_history(scenario_name=scenario_name, size=size)
        except Exception as exc:
            logger.exception(f"Failed to get scenario history (parameters: {body})")
            return str(exc), 500
